from vaderSentiment.vaderSentiment import SentimentIntensityAnalyzer

analyzer = SentimentIntensityAnalyzer()

# Returns a dict with the keys neg, neu, pos and compound
def assess(text):
    sentiment = analyzer.polarity_scores(text)
    return sentiment



import json

def convert_to_json(raw):
    # Setup variable to return at end
    convo = []
    formatted = raw.split('Q: ')
    for a in formatted:
        if len(a) > 0:
            actual_data = a.split('\nR: ')
            # Separate out queries and generate multiple if ; exists
            queries = actual_data[0].split('; ')
            # Strip all newlines
            actual_data[1] = actual_data[1].replace('\n', '')
            replies = []
            for i in actual_data[1].split('; '):
                data = i.split('|')
                refined = data[0].split('\\')
                modifiers = []
                try:
                    mods = refined[1].split('.')
                    for z in mods:
                        parts = mods.split('=')
                        modifiers += [ {'name': parts[0], 'val': int(parts[1])} ]
                except:
                    doNothing = True
                to_add = {'text': refined[0], 'weight': 1}
                to_add['modifiers'] = modifiers
                try:
                    converted = json.loads(data[1])
                    try:
                        to_add['image'] = converted['image']
                    except:
                        do_nothing = True
                except:
                    do_nothing = True
                replies += [to_add]
            convo += [{
                'starters': queries,
                'replies': replies
                }]
    return convo



import hashlib
import json

class MessageStats:
    log = {}
    file_name = ""
    def __init__(self, file_name):
        self.file_name = file_name

    def generate_message_hash(self, message):
        m = hashlib.md5()
        m.update(message.encode("utf-8"))
        digest = str(m.digest())
        return digest

    def log_occurence(self, message):
        key_hash = self.generate_message_hash(message)
        try:
            self.log[key_hash] += 1
        except:
            self.log.update({key_hash: 1})

    def retrieve_occurences(self, message):
        key_hash = self.generate_message_hash(message)
        try:
            return log[key_hash]
        except:
            return 0

    def save_log(self):
        raw_log = json.dumps(self.log)
        log_file = open(self.file_name, 'w')
        log_file.write(raw_log)

    def load_log(self):
        log_file = open(self.file_name)
        raw_log = log_file.read()
        log = json.loads(raw_log)
